@@ -22,7 +22,7 @@ function http_post_data($url, $data_string) {
   return $return_content;
  }
 
-$url = "http://192.168.2.1/goip/sendsms/";
+$url = "http://192.168.2.1/goip/querylines/";
 /*
 //$data = json_encode(array('a'=>"weqweqwe", 'b'=>2));
 //"auth":{"username":"goip","password":"goip"},
